@@ -138,57 +138,6 @@ rbind_helper <- function(x, cols) {
         fix.empty.names = FALSE, .id = NULL)
 }
 
-add_name_to_tests <- function(x, name) {
-    # add a column to a data.frame x with value name as character
-    UseMethod("add_name_to_tests")
-}
-
-#' @export
-add_name_to_tests.list <- function(x, name) {
-    return(lapply(x, add_name_to_tests, name))
-}
-
-#' @export
-add_name_to_tests.data.frame <- function(x, name, colname_for_variable = atable_options("colname_for_variable")) {
-    # the colnames of x are generated by format_tests(), which is user defined.
-    # there may be name clashes with atable_options('colname_for_variable')
-    b <- colname_for_variable %in% colnames(x)
-    if (b) {
-        stop("Name clash. ", colname_for_variable, " already in ", paste(colnames(x),
-            collapse = ", "), ". Please change atable_options('colname_for_variable')")
-    }
-
-    x[[colname_for_variable]] <- name
-    return(x)
-}
-
-
-add_name_to_statistics <- function(x, name) {
-    # add a column to a data.frame x with value name as character
-    UseMethod("add_name_to_statistics")
-}
-
-#' @export
-add_name_to_statistics.list <- function(x, name) {
-    return(lapply(x, add_name_to_statistics, name))
-}
-
-#' @export
-add_name_to_statistics.data.frame <- function(x, name, colname_for_variable = atable_options("colname_for_variable")) {
-
-    # there may be name clashes with atable_options('colname_for_variable')
-    b <- colname_for_variable %in% colnames(x)
-    if (b) {
-        stop("Name clash. ", colname_for_variable, " already in ", paste(colnames(x),
-            collapse = ", "), ". Please change atable_options('colname_for_variable') to something different")
-    }
-
-
-    x[[colname_for_variable]] <- name
-    x <- x[c(colname_for_variable, "tag", "value")]  # order of the columns
-
-    return(x)
-}
 
 
 
